==> 0.0.8.tar.gz: lib/yundian_ocr_platform_interface.dart <==
import 'package:plugin_platform_interface/plugin_platform_interface.dart';
import 'yundian_ocr_method_channel.dart';

import 'yundian_alive_method_channel.dart';

abstract class YundianOcrPlatform extends PlatformInterface {
  /// Constructs a YundianAlivePlatform.
  YundianOcrPlatform() : super(token: _token);

  static final Object _token = Object();

  static YundianOcrPlatform _instance = MethodChannelYundianOcr();

  /// The default instance of [YundianAlivePlatform] to use.
  ///
  /// Defaults to [MethodChannelYundianAlive].
  static YundianOcrPlatform get instance => _instance;

  /// Platform-specific implementations should set this with their own
  /// platform-specific class that extends [YundianAlivePlatform] when
  /// they register themselves.
  static set instance(YundianOcrPlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  Future<String?> ocrInit(bool isDebug, String appKey, String mchInfo, String riskInfo) {
    throw UnimplementedError('aliveInit() has not been implemented.');
  }

  Future<String?> ocrStartDetect(String authToken, bool isRealPeopleVerify) {
    throw UnimplementedError('aliveStartDetect() has not been implemented.');
  }

  onOcrResultListener(OcrEventHandler onEvent, OcrEventHandler onError) {
    throw UnimplementedError('onAliveResultListener() has not been implemented.');
  }


  Future<String?> ocrRelease() {
    throw UnimplementedError('ocrRelease() has not been implemented.');
  }

  Future<String?> setLayoutIdCardOcrId(String layoutIdName) {
    throw UnimplementedError('setLayoutIdCardOcrId() has not been implemented.');
  }

  Future<String?> setLayoutIdCardOcrSingleId(String layoutIdName) {
    throw UnimplementedError('setLayoutIdCardOcrSingleId() has not been implemented.');
  }

  Future<String?> setLayoutCarOcrId(String layoutIdName) {
    throw UnimplementedError('setLayoutCarOcrId() has not been implemented.');
  }

  Future<String?> setLayoutIdCardResultId(String layoutIdName) {
    throw UnimplementedError('setLayoutIdCardResultId() has not been implemented.');
  }

  Future<String?> setLayoutRealPeopleVerifyId(String layoutIdName) {
    throw UnimplementedError('setLayoutRealPeopleVerifyId() has not been implemented.');
  }

  Future<String?> setLayoutRealPeopleVerifySuccessId(String layoutIdName) {
    throw UnimplementedError('setLayoutRealPeopleVerifySuccessId() has not been implemented.');
  }

  Future<String?> setLayoutRealPeopleVerifyFailedId(String layoutIdName) {
    throw UnimplementedError('setLayoutRealPeopleVerifyFailedId() has not been implemented.');
  }

  Future<String?> setLayoutTakePhoneId(String layoutIdName) {
    throw UnimplementedError('setLayoutTakePhoneId() has not been implemented.');
  }

  Future<String?> setLayoutUploadIdCardId(String layoutIdName) {
    throw UnimplementedError('setLayoutUploadIdCardId() has not been implemented.');
  }

  Future<String?> setUploadTvBackTextColor(String color) {
    throw UnimplementedError('setUploadTvBackTextColor() has not been implemented.');
  }

  Future<String?> setUploadIvBackRes(int uploadIvBackRes) {
    throw UnimplementedError('setUploadIvBackRes() has not been implemented.');
  }
}

typedef OcrEventHandler = void Function(dynamic event);

==> 0.1.7.tar.gz: lib/yundian_ocr_platform_interface.dart <==
import 'package:plugin_platform_interface/plugin_platform_interface.dart';
import 'yundian_ocr_method_channel.dart';

import 'yundian_alive_method_channel.dart';

abstract class YundianOcrPlatform extends PlatformInterface {
  /// Constructs a YundianAlivePlatform.
  YundianOcrPlatform() : super(token: _token);

  static final Object _token = Object();

  static YundianOcrPlatform _instance = MethodChannelYundianOcr();

  /// The default instance of [YundianAlivePlatform] to use.
  ///
  /// Defaults to [MethodChannelYundianAlive].
  static YundianOcrPlatform get instance => _instance;

  /// Platform-specific implementations should set this with their own
  /// platform-specific class that extends [YundianAlivePlatform] when
  /// they register themselves.
  static set instance(YundianOcrPlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  Future<String?> ocrInit(bool isDebug, String appKey, String mchInfo, String riskInfo) {
    throw UnimplementedError('ocrInit() has not been implemented.');
  }

  Future<String?> ocrStartDetect(String authToken, bool isRealPeopleVerify) {
    throw UnimplementedError('ocrStartDetect() has not been implemented.');
  }

  onOcrResultListener(OcrEventHandler onEvent, OcrEventHandler onError) {
    throw UnimplementedError('onOcrResultListener() has not been implemented.');
  }


  Future<String?> ocrRelease() {
    throw UnimplementedError('ocrRelease() has not been implemented.');
  }

  Future<String?> setLayoutIdCardOcrId(String layoutIdName) {
    throw UnimplementedError('setLayoutIdCardOcrId() has not been implemented.');
  }

  Future<String?> setLayoutIdCardOcrSingleId(String layoutIdName) {
    throw UnimplementedError('setLayoutIdCardOcrSingleId() has not been implemented.');
  }

  Future<String?> setLayoutCarOcrId(String layoutIdName) {
    throw UnimplementedError('setLayoutCarOcrId() has not been implemented.');
  }

  Future<String?> setLayoutIdCardResultId(String layoutIdName) {
    throw UnimplementedError('setLayoutIdCardResultId() has not been implemented.');
  }

  Future<String?> setLayoutRealPeopleVerifyId(String layoutIdName) {
    throw UnimplementedError('setLayoutRealPeopleVerifyId() has not been implemented.');
  }

  Future<String?> setLayoutRealPeopleVerifySuccessId(String layoutIdName) {
    throw UnimplementedError('setLayoutRealPeopleVerifySuccessId() has not been implemented.');
  }

  Future<String?> setLayoutRealPeopleVerifyFailedId(String layoutIdName) {
    throw UnimplementedError('setLayoutRealPeopleVerifyFailedId() has not been implemented.');
  }

  Future<String?> setLayoutTakePhoneId(String layoutIdName) {
    throw UnimplementedError('setLayoutTakePhoneId() has not been implemented.');
  }

  Future<String?> setLayoutUploadIdCardId(String layoutIdName) {
    throw UnimplementedError('setLayoutUploadIdCardId() has not been implemented.');
  }

  Future<String?> setUploadTvBackTextColor(String color) {
    throw UnimplementedError('setUploadTvBackTextColor() has not been implemented.');
  }

  Future<String?> setUploadIvBackRes(int uploadIvBackRes) {
    throw UnimplementedError('setUploadIvBackRes() has not been implemented.');
  }
}

typedef OcrEventHandler = void Function(dynamic event);
